﻿using System;
using System.Linq;
using DasConzoleCore;
using DasConzoleCore.Commands;
using DasConzoleCore.UI;
using LyokoCMD.Sim;

namespace LyokoCMD.CommandLine.Commands
{
    public class ServiceCommand : Command
    {
        public override string[] Names => new string[] { "service" };
        public override string Description => "Gérer les services en arrière-plan.";
        public override string HelpText => @"Usage: service [list]
       service [start/stop/suspend] [nom(s)]

list     Lister les services disponibles.
start    Démarrer un service.
stop     Arrêter un service.
suspend  Suspendre un service.
[noms]   Nom(s) du ou des service's) sur le(s)quel(s) agir.";

        public override void Run(CommandApp app, string[] args)
        {
            Supercomputer sc = Game.Objects.Get<Supercomputer>();
            if (!sc.Running) throw new InvalidOperationException("Impossible de se connecter au supercalculateur.");
            if (args.Length < 1) args = new string[] { "list" };
            switch (args[0].Trim().ToLower())
            {
                case "list":
                    Console.WriteLine(Text.BuildTable(sc.Workers.All()));
                    break;
                case "start":
                    foreach (string name in args.Skip(1))
                    {
                        Console.WriteLine("Démarrage du service '{0}'", name);
                        sc.StartWorker(name);
                    }
                    break;
                case "suspend":
                    foreach (string name in args.Skip(1))
                    {
                        Console.WriteLine("Suspension du service '{0}'", name);
                        sc.SuspendWorker(name);
                    }
                    break;
                case "stop":
                    foreach (string name in args.Skip(1))
                    {
                        Console.WriteLine("Arrêt du service '{0}'", name);
                        sc.StartWorker(name);
                    }
                    break;
                default:
                    throw new ArgumentException(HelpText);
            }
        }
    }
}
