﻿using System;
using DasConzoleCore;
using DasConzoleCore.Commands;
using DasConzoleCore.UI;

namespace LyokoCMD.CommandLine.Commands
{
    class SettingsCommand : Command
    {
        public override string[] Names => new string[] { "settings" };
        public override string Description => "Gérer les paramètres de l'application.";
        public override string HelpText => @"Usage: settings list / load / save
settings get [clé]
settings set [clé] [valeur]
settings remove [clé]

list    Liste l'ensemble des paramètres.
load    Recharger les paramètres sauvegardés.
save    Sauvegarder les paramètres.
get     Obtenir la valeur d'un paramètre.
set     Définir la valeur d'un paramètre.
remove  Supprimer un paramètre.";
        public override void Run(CommandApp app, string[] args)
        {
            if (args.Length < 1) args = new string[] { "list" };
            switch (args[0].Trim().ToLower())
            {
                case "list":
                    Console.WriteLine(Text.BuildTable(app.Settings.ToDictionary()));
                    break;
                case "get":
                    if (args.Length < 2) throw new ArgumentException(HelpText);
                    Console.WriteLine(app.Settings.Get(args[1].Trim()));
                    break;
                case "set":
                    if (args.Length < 3) throw new ArgumentException(HelpText);
                    app.Settings.Set(args[1].Trim(), args[2]);
                    Console.WriteLine("Paramètre '{0}' défini à '{1}'.", args[1].Trim(), args[2]);
                    break;
                case "remove":
                    if (args.Length < 2) throw new ArgumentException(HelpText);
                    app.Settings.Remove(args[1].Trim());
                    Console.WriteLine("Paramètre '{0}' supprimé.", args[1].Trim());
                    break;
                case "load" when app is PersistenceCommandApp:
                    app.Settings = ((PersistenceCommandApp) app).SettingsPersistence.GetSettingsManager();
                    break;
                case "save" when app is PersistenceCommandApp:
                    ((PersistenceCommandApp) app).SettingsPersistence.Save(app.Settings);
                    break;
                default:
                    throw new ArgumentException(HelpText);
            }
        }
    }
}
