﻿using System;
using System.Linq;
using DasConzoleCore;
using DasConzoleCore.UI;
using DasConzoleCore.Commands;
using LyokoCMD.Sim;

namespace LyokoCMD.CommandLine.Commands
{
    public class SupercomputerCommand : Command
    {
        public override string[] Names => new string[] { "sc" };
        public override string Description => "Contrôler le supercalculateur.";
        public override string HelpText => @"Usage: sc [cooling] [start/stop/status]
start           Démarrer le supercalculateur
stop            Arrêter le supercalculateur
status          État général du supercalculateur
cooling start   Démarrer le système de refroidissement
cooling stop    Arrêter le système de refroidissement
cooling status  État du système de refroidissement";

        public override void Run(CommandApp app, string[] args)
        {
            if (args.Length < 1) args = new string[] { "status" };
            Supercomputer sc = Game.Objects.Get<Supercomputer>();
            switch (args[0].ToLower().Trim())
            {
                case "start":
                    Console.WriteLine("Tentative de démarrage du supercalculateur...");
                    sc.Start();
                    Console.WriteLine("Démarrage réussi");
                    break;
                case "stop":
                    Console.WriteLine("Arrêt du supercalculateur...");
                    sc.Stop();
                    Console.WriteLine("Supercalculateur éteint");
                    break;
                case "status":
                    Console.WriteLine("Supercalculateur " + (sc.Running ? "allumé" : "éteint"));
                    Text.WriteLine(
                        $"Température : {sc.Temperature} °C",
                        Colors.Parse(sc.Temperature > 60 ? app.Settings.Get("ErrorColor", "Red") : app.Settings.Get("ForeColor", "White"))
                    );
                    if (!sc.Running) return;
                    Console.WriteLine("{0} service(s) en cours d'exécution, {1} au total",
                        sc.Workers.All().Count(w => w.Running), sc.Workers.Count);
                    Console.WriteLine($"{sc.Tasks.Count} tâche(s) disponible(s)");
                    Console.WriteLine("{0} % d'énergie utilisée", Math.Round((sc.UsedEnergy / sc.TotalEnergy) * 100));
                    break;
                case "cooling":
                    if (args.Length < 2) args = new string[] {"cooling", "status"};
                    switch (args[1].ToLower().Trim())
                    {
                        case "start":
                            Console.WriteLine("Tentative de démarrage du système de refroidissement...");
                            sc.StartCooling();
                            Console.WriteLine("Système de refroidissement activé.");
                            break;
                        case "stop":
                            Console.WriteLine("Arrêt du système de refroidissement...");
                            sc.StopCooling();
                            Console.WriteLine("Système de refroidissement désactivé.");
                            break;
                        case "status":
                            Console.WriteLine("Système de refroidissement " + (sc.Cooling ? "actif" : "inactif"));
                            break;
                        default:
                            throw new ArgumentException(HelpText);
                    }
                    break;
                default:
                    throw new ArgumentException(HelpText);
            }
        }
    }
}
