using System;
using System.Linq;
using DasConzoleCore;
using DasConzoleCore.Commands;
using DasConzoleCore.Data;
using LyokoCMD.CommandLine.Commands;
using LyokoCMD.Sim;

namespace LyokoCMD.CommandLine
{
    class Program
    {
        static void Main(string[] args)
        {
            CommandApp app = new PersistenceCommandApp("LyokoCMD", new System.Version(0,1), new TextSettingsPersistenceManager("settings.txt"));
            Game.registerObjects();
            app.AddCommand(
                new ExitCommand(new[] {"exit"}),
                new EchoCommand(new[] {"echo"}),
                new HelpCommand(new[] {"help"}),
                new AboutCommand(),
                new ClearCommand(),
                new SettingsCommand(),
                new EnergyCommand(),
                new SupercomputerCommand(),
                new TaskCommand(),
                new ServiceCommand(),
                new VirtualizationCommand(),
                new TimeWarpCommand(),
                new VirtualWorldCommand()
            );
            app.AppStartup += new System.EventHandler(app_AppStartup);
            app.AppStop += new System.EventHandler(app_AppStop);
            app.DebugMode = args.Intersect(new [] {"-d", "-debug", "--debug", "/d", "/debug"}, StringComparer.CurrentCultureIgnoreCase).Any();
            app.Run();
        }

        static void app_AppStartup(object sender, System.EventArgs e)
        {
            CommandApp app = (CommandApp)sender;
            System.Console.Clear();
            app.TryParse("about short");
            app.TryParse("echo Pour obtenir de l'aide, tapez 'help'.");
        }

        static void app_AppStop(object sender, System.EventArgs e)
        {
            Array.ForEach(Game.Objects.Get<Supercomputer>().Workers.All(), w => w.ForceStop());
            var app = (PersistenceCommandApp)sender;
            app.SettingsPersistence.Save(app.Settings);
            System.Console.Clear();
        }
    }
}
