using LyokoCMD.Sim.EnergyProviders;
using LyokoCMD.Sim.Tasks;
using LyokoCMD.Sim.Virtual;
using LyokoCMD.Sim.Virtual.World;
using LyokoCMD.Sim.Workers;

namespace LyokoCMD.Sim
{
    public static class Game
    {
        public static ObjectsRegistry Objects = new ObjectsRegistry();

        public static void registerObjects()
        {
            Supercomputer sc = new Supercomputer();
            sc.EnergyProviders.Register(new NuclearCell());
            // Lyoko
            VirtualWorld lyoko = new VirtualWorldBuilder("Lyoko")
                .AddSector("Territoire Montagne", "montagne")
                .AddSector("Territoire Désert", "desert")
                .AddSector("Territoire Forêt", "foret")
                .AddSector("Territoire Banquise", "banquise")
                .AddTowers(20)
                .AddWayTowers()
                .AddSector("5ème territoire", "cinq", true, 1)
                .Build();
            sc.Workers.Register(new VirtualWorldWorker(lyoko));
            Objects.Register(lyoko, "Lyoko");
            // Lyokoguerriers
            Human aelita = new Human("Aelita", true) {DNAStatus = DNAStatus.Missing};
            Objects.Register(aelita, "Aelita");
            Objects.Register(new Human("Odd"), "Odd");
            Objects.Register(new Human("Ulrich"), "Ulrich");
            Objects.Register(new Human("Yumi"), "Yumi");
            // Véhicules
            Objects.Register(new Vehicle("Overboard"), "Overboard");
            Objects.Register(new Vehicle("Overbike"), "Overbike");
            Objects.Register(new Vehicle("Overwing"), "Overwing");
            // Virtualisation
            sc.Tasks.Register(new VirtualizationTask());
            // Retour vers le passé
            TimeWarpEnergyProvider tw = new TimeWarpEnergyProvider();
            sc.EnergyProviders.Register(tw);
            sc.Tasks.Register(new TimeWarpTask());
            sc.Workers.Register(new TimeWarpWorker());
            Objects.Register(sc);
        }
    }
}
