﻿using System;
using System.Collections.Generic;
using System.Linq;
using LyokoCMD.Sim.Extensions;

namespace LyokoCMD.Sim
{
    /// <summary>
    /// A registry capable of holding named and unnamed objects.
    /// </summary>
    /// <typeparam name="BaseT">Base type of all objects of the registry.</typeparam>
    public class ObjectsRegistry<BaseT>
    {
        protected Dictionary<BaseT, string> objects = new Dictionary<BaseT,string>();

        public void Register(BaseT obj) => Register(obj, String.Empty);

        public void Register(BaseT obj, string name) => objects.Add(obj, name);

        public T Get<T>() where T: BaseT => (T)objects.First(o => o.Key.CanCast<T>()).Key;

        public T Get<T>(string name) where T: BaseT => (T)objects.First(o => o.Key.CanCast<T>() && o.Value == name).Key;

        public BaseT[] All() => objects.Keys.ToArray();

        public T[] All<T>() where T: BaseT => objects.Where(o => o.Key.CanCast<T>()).Select(p => p.Key).Cast<T>().ToArray();

        public T[] All<T>(string name) where T: BaseT => objects.Where(o => o.Key.CanCast<T>() && o.Value == name).Select(p => p.Key).Cast<T>().ToArray();

        public int Count => objects.Count;

        public string[] Names => objects.Values.Where(o => o != String.Empty).ToArray();

        public Dictionary<BaseT, string> NamedObjects => objects.Where(p => p.Value != String.Empty).ToDictionary(p => p.Key, p => p.Value);
    }

    /// <summary>
    /// A registry capable of holding named and unnamed objects.
    /// </summary>
    public class ObjectsRegistry : ObjectsRegistry<Object> { }
}
