﻿using System;

namespace LyokoCMD.Sim.Virtual
{
    public class Coordinates : Tuple<double, double>
    {
        public Coordinates(Tuple<double, double> tuple) : this(tuple.Item1, tuple.Item2) { }
        public Coordinates(Coordinates coords) : this(coords.Item1, coords.Item2) { }
        public Coordinates(double lat, double lng) : base(lat, lng)
        {
            if (lat < -90.0 || lat > 90.0) throw new ArgumentOutOfRangeException("lat", lat, "La latitude doit être comprise entre -90 et 90 degrés.");
            if (lng < -180.0 || lng > 180.0) throw new ArgumentOutOfRangeException("lng", lng, "La longitude doit être comprise entre -180 et 180 degrés.");
        }

        public double Latitude => Math.Abs(Item1);
        public double Longitude => Math.Abs(Item2);
        public Direction LatDirection => Item1 >= 0.0 ? Direction.North : Direction.South;
        public Direction LngDirection => Item2 >= 0.0 ? Direction.West : Direction.East;

        public override string ToString() => String.Format("{0}° {1}, {2}° {3}", Latitude, LatDirection, Longitude, LngDirection);

        public static Coordinates Zero = new Coordinates(0, 0);
        public static Coordinates MinValue = new Coordinates(-90.0, -180.0);
        public static Coordinates MaxValue = new Coordinates(90.0, 180.0);

        public static Coordinates Random()
        {
            Random rand = new Random();
            return new Coordinates((rand.NextDouble() * 180.0) - 90.0, (rand.NextDouble() * 360.0) - 180.0);
        }
    }

    public enum Direction
    {
        North = 'N',
        South = 'S',
        East = 'E',
        West = 'W'
    }
}
