﻿using System;

namespace LyokoCMD.Sim.Virtual
{
    /// <summary>
    /// Spécifie qu'un objet peut être virtualisable sur Lyoko.
    /// </summary>
    public abstract class Virtualizable
    {
        protected bool _IsVirtualized = false;
        public bool Virtualized => _IsVirtualized;

        protected string _Name;
        public string Name => _Name;

        protected Coordinates _Coordinates;
        public Coordinates Coordinates => _Coordinates;

        protected bool _CanMaterialize;
        public virtual bool CanMaterialize => _CanMaterialize;

        protected Virtualizable(string name, Coordinates coords = null, bool canMaterialize = true)
        {
            _Name = name;
            _Coordinates = coords;
            _IsVirtualized = coords != null;
            _CanMaterialize = canMaterialize;
        }

        public virtual void Virtualize()
        {
            if (Virtualized) throw new InvalidOperationException("Cette entité a déjà été virtualisée.");
            else _IsVirtualized = true;
        }

        public virtual void Materialize() {
            if (!Virtualized) {throw new InvalidOperationException("Cette entité n'a pas été virtualisée.");}
            if (!CanMaterialize) throw new InvalidOperationException("Cette entité ne peut être dévirtualisée");
            _IsVirtualized = false;
        }

        public override string ToString() => Coordinates is null ? Name : $"{Name}, {Coordinates}";
    }
}
