using System;
using System.Collections.Generic;

namespace LyokoCMD.Sim.Virtual
{
    public abstract class VirtualizableVirtualizableContainer : Virtualizable, IVirtualizableContainer {

        public List<Virtualizable> Objects { get; }

        public VirtualizableVirtualizableContainer(string name, Coordinates coords = null, bool canMaterialize = true)
            : base(name, coords,canMaterialize) => Objects = new List<Virtualizable>();

        public void Virtualize(Virtualizable obj) {
            if (Objects.Contains(obj)) throw new InvalidOperationException("Cette entité est déjà virtualisée.");
            obj.Virtualize();
            Objects.Add(obj);
        }

        public override void Materialize() {
            this.MaterializeAll();
            base.Materialize();
        }

        public void Materialize(Virtualizable obj) {
            if(!Objects.Contains(obj)) throw new InvalidOperationException("Cette entité n'est pas virtualisée ici.");
            obj.Materialize();
            Objects.Remove(obj);
        }

        public void MaterializeAll() {
            Objects.ForEach(this.Materialize);
        }
    }
}
