﻿using System;
using System.Collections.Generic;
using LyokoCMD.Sim.Virtual.Towers;

namespace LyokoCMD.Sim.Virtual.World
{
    /// <summary>
    /// Classe simplifiant la création d'un monde virtuel.
    /// </summary>
    class VirtualWorldBuilder
    {
        private string Name;
        private List<Sector> Sectors = new List<Sector>();

        public VirtualWorldBuilder(String name) => this.Name = name;

        public VirtualWorldBuilder AddSector(string name, string shortName, bool locked = false)
        {
            Sectors.Add(new Sector(name, shortName, locked));
            return this;
        }

        public VirtualWorldBuilder AddSector(string name, string shortName, bool locked, int towerCount)
        {
            Sector s = new Sector(name, shortName, locked);
            s.CreateTowers(towerCount);
            return this;
        }

        public VirtualWorldBuilder AddTowers(int towerCount)
        {
            Sectors.ForEach(s => s.CreateTowers(towerCount));
            return this;
        }

        public VirtualWorldBuilder AddWayTowers()
        {
            for (int i = 0; i < Sectors.Count; i++)
                Sectors[i].Objects.Add(new WayTower(Sectors[(i + 1) % Sectors.Count]));
            return this;
        }

        public VirtualWorld Build() => new VirtualWorld(Name, Sectors);
    }
}
